--[[=============================================================================
    Command Functions Received From Camera Proxy to the Driver

    Copyright 2017 Control4 Corporation. All Rights Reserved.
===============================================================================]]

require "lib.c4_log"

-- This macro is utilized to identify the version string of the driver template version used.
if (TEMPLATE_VERSION ~= nil) then
	TEMPLATE_VERSION.lock_proxy_commands = "2017.09.11"
end


---------------------------------------------------------------


function PRX_CMD.PAN_LEFT(idBinding, tParams)
	LogTrace("PRX_CMD.PAN_LEFT")
	if (TheCamera) then
		TheCamera:PrxPanLeft(tParams)
	end
end


function PRX_CMD.PAN_RIGHT(idBinding, tParams)
	LogTrace("PRX_CMD.PAN_RIGHT")
	if (TheCamera) then
		TheCamera:PrxPanRight(tParams)
	end
end


function PRX_CMD.PAN_SCAN(idBinding, tParams)
	LogTrace("PRX_CMD.PAN_SCAN")
	if (TheCamera) then
		TheCamera:PrxPanScan(tParams)
	end
end


function PRX_CMD.TILT_UP(idBinding, tParams)
	LogTrace("PRX_CMD.TILT_UP")
	if (TheCamera) then
		TheCamera:PrxTiltUp(tParams)
	end
end


function PRX_CMD.TILT_DOWN(idBinding, tParams)
	LogTrace("PRX_CMD.TILT_DOWN")
	if (TheCamera) then
		TheCamera:PrxTiltDown(tParams)
	end
end


function PRX_CMD.TILT_SCAN(idBinding, tParams)
	LogTrace("PRX_CMD.TILT_SCAN")
	if (TheCamera) then
		TheCamera:PrxTiltScan(tParams)
	end
end


function PRX_CMD.ZOOM_IN(idBinding, tParams)
	LogTrace("PRX_CMD.ZOOM_IN")
	if (TheCamera) then
		TheCamera:PrxZoomIn(tParams)
	end
end


function PRX_CMD.ZOOM_OUT(idBinding, tParams)
	LogTrace("PRX_CMD.ZOOM_OUT")
	if (TheCamera) then
		TheCamera:PrxZoomOut(tParams)
	end
end


function PRX_CMD.FOCUS_NEAR(idBinding, tParams)
	LogTrace("PRX_CMD.FOCUS_NEAR")
	if (TheCamera) then
		TheCamera:PrxFocusNear(tParams)
	end
end


function PRX_CMD.FOCUS_FAR(idBinding, tParams)
	LogTrace("PRX_CMD.FOCUS_FAR")
	if (TheCamera) then
		TheCamera:PrxFocusFar(tParams)
	end
end


function PRX_CMD.IRIS_OPEN(idBinding, tParams)
	LogTrace("PRX_CMD.IRIS_OPEN")
	if (TheCamera) then
		TheCamera:PrxIrisOpen(tParams)
	end
end


function PRX_CMD.IRIS_CLOSE(idBinding, tParams)
	LogTrace("PRX_CMD.IRIS_CLOSE")
	if (TheCamera) then
		TheCamera:PrxIrisClose(tParams)
	end
end


function PRX_CMD.AUTO_FOCUS(idBinding, tParams)
	LogTrace("PRX_CMD.AUTO_FOCUS")
	if (TheCamera) then
		TheCamera:PrxAutoFocus(tParams)
	end
end


function PRX_CMD.AUTO_IRIS(idBinding, tParams)
	LogTrace("PRX_CMD.AUTO_IRIS")
	if (TheCamera) then
		TheCamera:PrxAutoIris(tParams)
	end
end


function PRX_CMD.HOME(idBinding, tParams)
	LogTrace("PRX_CMD.HOME")
	if (TheCamera) then
		TheCamera:PrxHome(tParams)
	end
end


function PRX_CMD.MOVE_TO(idBinding, tParams)
	LogTrace("PRX_CMD.")
	if (TheCamera) then
		TheCamera:PrxMoveTo(tParams)
	end
end


function PRX_CMD.NIGHT_MODE(idBinding, tParams)
	LogTrace("PRX_CMD.NIGHT_MODE")
	if (TheCamera) then
		TheCamera:PrxNightMode(tParams)
	end
end


function PRX_CMD.PRESET(idBinding, tParams)
	LogTrace("PRX_CMD.PRESET")
	if (TheCamera) then
		TheCamera:PrxPreset(tParams)
	end
end


function PRX_CMD.SET_ADDRESS(idBinding, tParams)
	LogTrace("PRX_CMD.SET_ADDRESS")
	if (TheCamera) then
		TheCamera:PrxSetAddress(tParams)
	end
end


function PRX_CMD.SET_HTTP_PORT(idBinding, tParams)
	LogTrace("PRX_CMD.SET_HTTP_PORT")
	if (TheCamera) then
		TheCamera:PrxSetHttpPort(tParams)
	end
end


function PRX_CMD.SET_RTSP_PORT(idBinding, tParams)
	LogTrace("PRX_CMD.SET_RTSP_PORT")
	if (TheCamera) then
		TheCamera:PrxSetRtspPort(tParams)
	end
end


function PRX_CMD.SET_AUTHENTICATION_REQUIRED(idBinding, tParams)
	LogTrace("PRX_CMD.SET_AUTHENTICATION_REQUIRED")
	if (TheCamera) then
		TheCamera:PrxSetAuthenticationRequired(tParams)
	end
end


function PRX_CMD.SET_AUTHENTICATION_TYPE(idBinding, tParams)
	LogTrace("PRX_CMD.SET_AUTHENTICATION_TYPE")
	if (TheCamera) then
		TheCamera:PrxSetAuthenticationType(tParams)
	end
end


function PRX_CMD.SET_USERNAME(idBinding, tParams)
	LogTrace("PRX_CMD.SET_USERNAME")
	if (TheCamera) then
		TheCamera:PrxSetUserName(tParams)
	end
end


function PRX_CMD.SET_PASSWORD(idBinding, tParams)
	LogTrace("PRX_CMD.SET_PASSWORD")
	if (TheCamera) then
		TheCamera:PrxSetPassword(tParams)
	end
end


function PRX_CMD.SET_PUBLICLY_ACCESSIBLE(idBinding, tParams)
	LogTrace("PRX_CMD.SET_PUBLICLY_ACCESSIBLE")
	if (TheCamera) then
		TheCamera:PrxSetPubliclyAccessible(tParams)
	end
end

---------------------------------------------------------------
---------------------------------------------------------------

function UI_REQ.GET_SNAPSHOT_QUERY_STRING(tParams)
	if (TheCamera) then
		return TheCamera:ReqGetSnapshotQueryString(tParams)
	else
		LogError("UI_REQ.GET_SNAPSHOT_QUERY_STRING  Camera not defined")
		return ""
	end
end

--[[
	Return the query string required for an HTTP image push URL request.
--]]
function UI_REQ.GET_MJPEG_QUERY_STRING(tParams)
	if (TheCamera) then
		return TheCamera:ReqGetMjpegQueryString(tParams)
	else
		LogError("UI_REQ.GET_MJPEG_QUERY_STRING  Camera not defined")
		return ""
	end
end

--[[
	Return the query string required to establish Rtsp connection. May be empty string.
--]]
function UI_REQ.GET_RTSP_H264_QUERY_STRING(tParams)
	if (TheCamera) then
		return TheCamera:ReqGetRtspH264QueryString(tParams)
	else
		LogError("UI_REQ.GET_RTSP_H264_QUERY_STRING  Camera not defined")
		return ""
	end
end



ldCameraCommands = true		--- for development


