--[[=============================================================================
    File is: camera_requests.lua

    Copyright 2021 Wirepath Home Systems, LLC. All Rights Reserved.
===============================================================================]]

if (TEMPLATE_VERSION ~= nil) then
	TEMPLATE_VERSION.camera_requests = "2019.04.09"
end
	
	
--================================================================

function CameraReq_SnapshotQueryString(tParams)
	LogTrace("CameraReq_SnapshotQueryString")
	return "snap"
end

-- http version
function CameraReq_MjpegQueryString(tParams)
	LogTrace("CameraReq_MjpegQueryString")
	return "getimage"
end


function CameraReq_RtspH264QueryString(tParams)
	LogTrace("CameraReq_RtspH264QueryString")
	
	tParams = tParams or {}
	gH264TEXT = gH264TEXT or {}		-- a little paranoia
	
	local size_x = tonumber(tParams["SIZE_X"]) or 640
	local size_y = tonumber(tParams["SIZE_Y"]) or 480
	local delay = tonumber(tParams["DELAY"]) or 50

	local min = 1000000
	local minString = "rtsph264480p"	-- safe default value
	local best = -1
	local Kludge480Count = 0			-- unfortunately, there are two possible resolutions with
										-- a y_size of 480. 720x480 and 640x480.
										-- Put in some hackary to choose if there is a conflict

	local UseString = ""
	for RtspStr, YRes in pairs(gH264TEXT) do
		if(YRes < min) then
			min = YRes
			minString = RtspStr
		end
		
		if(YRes == 480) then
			Kludge480Count = Kludge480Count + 1
		end
		
		if((YRes <= size_y) and (YRes > best)) then
			best = YRes
			UseString = RtspStr
		end
	end

	if(UseString == "") then
		-- didn't find anything we like, try going with the lowest option
		best = min
		UseString = minString
	end
	
	if((best == 480) and (Kludge480Count > 1)) then
		-- we chose 480, but there are multiple possibilites
		-- if the x_size is 720 or greater, use that.  If it's less than 720, use the 640 resolutions
		UseString = (size_x >= 720) and "rtsph264480p" or "rtsph264vga"
		--                                 ^^ 720 ^^         ^^ 640 ^^
	end
	
	local H264QueryString = C4:XmlEscapeString(UseString)
	LogDebug("H264QueryString is: %s", H264QueryString)
	return H264QueryString
	
end


ld_camera_request = true		-- for development


