--[[=============================================================================
	File is: pakedge_detection.lua  (PakedgeVision IPC PTZ)
	
    Copyright 2021 Wirepath Home Systems, LLC. All Rights Reserved.
===============================================================================]]

require "c4hooks.c4hook_sensor"

Pakedge_Detection = inheritsFrom(C4H_Sensor)

Pakedge_Detection.AllDetections = {}


function Pakedge_Detection.SetupDetections()
	Pakedge_Detection._NextContactBinding = 101
end


function Pakedge_Detection.ClearAllDetections()
	for _, TargDetection in pairs(Pakedge_Detection.AllDetections) do
		TargDetection:destruct()
	end
	
	Pakedge_Detection._NextContactBinding = 101
end


function Pakedge_Detection.DetectionExists(CheckDetection)
	return (Pakedge_Detection.AllDetections[CheckDetection] ~= nil)
end


function Pakedge_Detection.AddNewDetection(DetectionName)
	Pakedge_Detection:new(Pakedge_Detection._NextContactBinding, DetectionName)
	Pakedge_Detection._NextContactBinding = Pakedge_Detection._NextContactBinding + 1
end


function Pakedge_Detection.StartDetection(DetectionName)
	local TargDetection = Pakedge_Detection.AllDetections[DetectionName]
	if(TargDetection ~= nil) then
		TargDetection:DetectionStart()
	else
		LogWarn("Pakedge_Detection.StartDetection  Undefined detection: %s", tostring(DetectionName))
	end
end

--==============================================================================
--==============================================================================

function Pakedge_Detection:construct(BindingID, DetectionName)
	self:super():construct(BindingID)

	self._Name = DetectionName
	
	Pakedge_Detection.AllDetections[self._Name] = self

	self._DwellTimer = CreateTimer("Dwell_" .. self._Name, 5, "SECONDS", OnDwellExpired, false, self)

	C4:AddDynamicBinding(self._BindingID, "CONTROL", true, self._Name .. " Detection", "CONTACT_SENSOR", false, false)
	
	self:SetStateFromDevice(false)
end


function Pakedge_Detection:destruct()
	Pakedge_Detection.AllDetections[self._Name] = nil
	self._DwellTimer:KillTimer()
	C4:RemoveDynamicBinding(self._BindingID)
	self:super():destruct()
end


function Pakedge_Detection:DetectionStart()
	self:ReceivedStateFromDevice(true)
	self._DwellTimer:StartTimer()
end


function Pakedge_Detection:DetectionEnd()
	self._DwellTimer:KillTimer()
	self:ReceivedStateFromDevice(false)
end


function OnDwellExpired (TargDetection)
	if(TargDetection ~= nil) then
		TargDetection:DetectionEnd()
	else
		LogError("OnDwellExpired  Invalid Detection")
	end
end


ld_pakedgedetection = true			-- for development

