--[[=============================================================================
	File is: pakedge_email.lua
	
    Copyright 2021 Wirepath Home Systems, LLC. All Rights Reserved.
===============================================================================]]


EmailControl = {
	_ToAddress = nil,
	_FromAddress = nil,
	_Server = nil,
	_Port = nil,
	
	_SSL = 'Select',
	_Account = nil,
	_Password = nil,

	_Subject = nil,
	_Message = 'Snapshot from Pakedge Camera',
	
	_EmailEnabled = false
}

function EmailControl:SetToAddress(NewAddress)
	if (NewAddress:match("[A-Za-z0-9%.%%%+%-]+@[A-Za-z0-9%.%%%+%-]+%.%w%w%w?%w?")) then
		self._ToAddress = NewAddress
		url = BuildHTTPString('setnotification?rcvaddress=' .. self._ToAddress)
		UrlGet(url)
	else
		LogWarn("Invalid MailTo Address: %s", tostring(NewAddress))
		C4:UpdateProperty("Email To Address","Invalid Email")
	end
end

function EmailControl:GetToAddress()
	return self._ToAddress
end


function EmailControl:SetFromAddress(NewAddress)
	if (NewAddress:match("[A-Za-z0-9%.%%%+%-]+@[A-Za-z0-9%.%%%+%-]+%.%w%w%w?%w?")) then
		self._FromAddress = NewAddress
		if (self._FromAddress:match("[A-Za-z0-9%.%%%+%-]+@gmail+%.%w%w%w?%w?")) then		
			self:SetServer(string.gsub(self._FromAddress, '[A-Za-z0-9%.%%%+%-]+@gmail', 'smtp.gmail'))
			self:SetPort(465)
		
		elseif (self._FromAddress:match("[A-Za-z0-9%.%%%+%-]+@yahoo+%.%w%w%w?%w?")) then	
			self:SetServer(string.gsub(self._FromAddress, '[A-Za-z0-9%.%%%+%-]+@yahoo', 'smtp.mail.yahoo'))
			self:SetPort(465)
		
		elseif (self._FromAddress:match("[A-Za-z0-9%.%%%+%-]+@hotmail+%.%w%w%w?%w?")) then	
			self:SetServer(string.gsub(self._FromAddress, '[A-Za-z0-9%.%%%+%-]+@hotmail', 'smtp.live'))
			self:SetPort(587)
		
		elseif (self._FromAddress:match("[A-Za-z0-9%.%%%+%-]+@zoho+%.%w%w%w?%w?")) then	
			self:SetServer(string.gsub(self._FromAddress, '[A-Za-z0-9%.%%%+%-]+@zoho', 'smtp.zoho'))
			self:SetPort(465)
		
		elseif (self._FromAddress:match("[A-Za-z0-9%.%%%+%-]+@mail+%.%w%w%w?%w?")) then	
			self:SetServer(string.gsub(self._FromAddress, '[A-Za-z0-9%.%%%+%-]+@mail', 'smtp.mail'))
			self:SetPort(465)
		
		end
		
		url = BuildHTTPString('setnotification?sndaddress=' .. self._FromAddress ..'&smtpserver=' .. self._Server .. '&smtp_email_port=' .. self._Port)
		UrlGet(url)			
	else
		LogWarn("Invalid MailFrom Address: %s", tostring(NewAddress))
		C4:UpdateProperty("Email From Address", "Invalid Email")
	end
end

function EmailControl:GetFromAddress()
	return self._FromAddress
end


function EmailControl:SetServer(NewServer)
	self._Server = NewServer
	url = BuildHTTPString('setnotification?smtpserver=' .. self._Server)
	UrlGet(url)
	
	C4:UpdateProperty("SMTP Server", self._Server)
end


function EmailControl:GetServer()
	return self._Server
end


function EmailControl:SetPort(NewPort)
	self._Port = NewPort
	url = BuildHTTPString('setnotification?smtp_email_port=' .. self._Port)
	UrlGet(url)
	C4:UpdateProperty("SMTP Port", self._Port)
end


function EmailControl:GetPort()
	return self._Port
end


function EmailControl:SetSubject(NewSubject)
	self._Subject = string.gsub (NewSubject, ' ', '%%20')
	url = BuildHTTPString('trigger?subject=' .. self._Subject .. '&content=' .. self._Message)
	UrlGet(url)
end


function EmailControl:GetSubject()
	return self._Subject
end


function EmailControl:SetMessage(NewMessage)
	self._Message = string.gsub (NewMessage, ' ', '%%20')
	url = BuildHTTPString('trigger?subject=' .. self._Subject .. '&content=' .. self._Message)
	UrlGet(url)
end


function EmailControl:GetMessage()
	return self._Message
end


function EmailControl:SetSSLLogin(NewLogin)
	self._SSL = NewLogin
	if (NewLogin == "Yes") then
		url = BuildHTTPString('setnotification?smtp_auth_mode=1&Authentication=1')
		UrlGet(url)
		self:SetPort(465)
			
	elseif (NewLogin == "No") then
		url = BuildHTTPString('setnotification?smtp_auth_mode=0&Authentication=1')
		UrlGet(url)
	end
end


function EmailControl:GetSSLLogin()
	return self._SSL
end


function EmailControl:SetAccount(NewAccount)
	self._Account = NewAccount
	if((self._Account ~= nil) and (self._Account ~= 'nil') and (self._Account ~= "")) then
		url = BuildHTTPString('setnotification?authaccount=' .. self._Account .. '&Authentication=1')	
		UrlGet(url)	
	else
		LogWarn("Please check your smtp account")
	end
end


function EmailControl:GetAccount()
	return self._Account
end


function EmailControl:SetPassword(NewPassword)
	self._Password = NewPassword
	if((self._Password ~= nil) and (self._Password ~= "")) then
		url = BuildHTTPString('setnotification?authpassword=' .. self._Password .. '&Authentication=1')
		UrlGet(url)
	else	
		LogWarn("Please check your smtp password")
	end
end


function EmailControl:GetPassword()
	return self._Password
end


function EmailControl:Update()
	if ((self._ToAddress ~= nil) and (self._ToAddress ~= 'Invalid Email') and 
		(self._FromAddress ~= nil) and (self._FromAddress ~= 'Invalid Email') and 
		(self._Server ~= nil) and 
		(self._Port ~= nil) and 
		(self._Account ~= nil) and 
		(self._Password ~= nil) and 
		(self._SSL ~= 'Select')) then
		LogDebug("EmailControl:Update  - All items checked and valid")

		local url = 'setnotification?rcvaddress=' .. self._ToAddress
		url = url .. '&sndaddress=' .. self._FromAddress
		url = url .. '&smtpserver=' .. self._Server
		url = url .. '&smtp_email_port=' .. self._Port

		if((self._Account ~= nil) and (self._Account ~= "") and (self._Password ~= nil) and (self._Password ~= "")) then
			url = url .. '&authaccount=' .. self._Account
			url = url .. '&authpassword=' .. self._Password
			url = url .. '&Authentication=1'
		else		
			LogWarn("EmailControl:Update Please check your smtp account or smtp password")
		end

		if (self._SSL == 'Yes') then
			url = url .. '&smtp_auth_mode=1'
		else
			url = url .. '&smtp_auth_mode=0'
		end

		url = BuildHTTPString(url)
		UrlGet(url)

		url = BuildHTTPString('trigger?subject=' .. self._Subject .. '&content=' .. self._Message)
		UrlGet(url)
	else
		LogWarn("EmailControl:Update  Not all fields are valid")
	end
end


function EmailControl:SendSnapshot()
	LogTrace("EmailControl:SendSnapshot")
	
	if((self._Account ~= nil) and (self._Account ~= "") and (self._Password ~= nil) and (self._Password ~= "")) then
		local url = BuildHTTPString('trigger?sendmail=1&subject=' .. self._Subject .. '&content=' .. self._Message)
		UrlGet(url)
	else
		LogWarn("EmailControl:SendSnapshot  Please check your smtp account or smtp password")
	end
end


function EmailControl:SetEnableFlag(EnableIt)
	self._EmailEnabled = EnableIt
	self:UpdateEmailProperties()
end

function EmailControl:IsEnabled()
	return self._EmailEnabled
end

function EmailControl:UpdateEmailProperties()
	local HideShow = self._EmailEnabled and 0	or 1		-- 0 -> Show   1 --> Hide
	LogTrace("EmailControl:UpdateEmailProperties  Value is: %d", HideShow)
	
	C4:UpdateProperty("Show Email Settings", (HideShow == 0) and "Show" or "Hide")

	C4:SetPropertyAttribs("Email To Address",	HideShow)
	C4:SetPropertyAttribs("Email From Address",	HideShow)
	C4:SetPropertyAttribs("SMTP Server",		HideShow)
	C4:SetPropertyAttribs("SMTP Port",			HideShow)
	C4:SetPropertyAttribs("SSL Login",			HideShow)
	C4:SetPropertyAttribs("SMTP Account",		HideShow)
	C4:SetPropertyAttribs("SMTP Password",		HideShow)
	C4:SetPropertyAttribs("Email Subject",		HideShow)
	C4:SetPropertyAttribs("Email Message",		HideShow)
	
end

--==========================================================================
-- Email Properties
--==========================================================================

function ON_PROPERTY_CHANGED.ShowEmailSettings(propertyValue)
	LogTrace("ON_PROPERTY.ShowEmailSettings: " .. propertyValue)
	EmailControl:SetEnableFlag(propertyValue == "Show")
end


function ON_PROPERTY_CHANGED.EmailToAddress(propertyValue)
	LogTrace("ON_PROPERTY.EmailToAddress: " .. propertyValue)
	EmailControl:SetToAddress(propertyValue)
end

function ON_PROPERTY_CHANGED.EmailFromAddress(propertyValue)
	LogTrace("ON_PROPERTY.EmailFromAddress: " .. propertyValue)
	EmailControl:SetFromAddress(propertyValue)
end

function ON_PROPERTY_CHANGED.EmailSubject(propertyValue)
	LogTrace("ON_PROPERTY.EmailSubject: " .. propertyValue)
	EmailControl:SetSubject(propertyValue)
end

function ON_PROPERTY_CHANGED.EmailMessage(propertyValue)
	LogTrace("ON_PROPERTY_CHANGED.EmailMessage " .. propertyValue)
	EmailControl:SetMessage(propertyValue)
end

function ON_PROPERTY_CHANGED.SMTPServer(propertyValue)
	LogTrace("ON_PROPERTY_CHANGED.SMTPServer " .. propertyValue)
	EmailControl:SetServer(propertyValue)
end

function ON_PROPERTY_CHANGED.SMTPPort(propertyValue)
	LogTrace("ON_PROPERTY_CHANGED.SMTPPort " .. propertyValue)
	EmailControl:SetPort(propertyValue)
end

function ON_PROPERTY_CHANGED.SSLLogin(propertyValue)
	LogTrace("ON_PROPERTY_CHANGED.SSLLogin " .. propertyValue)
	EmailControl:SetSSLLogin(propertyValue)
end

function ON_PROPERTY_CHANGED.SMTPAccount(propertyValue)
	LogTrace("ON_PROPERTY_CHANGED.SMTPAccount " .. propertyValue)
	EmailControl:SetAccount(propertyValue)
end
			
function ON_PROPERTY_CHANGED.SMTPPassword(propertyValue)
	LogTrace("ON_PROPERTY_CHANGED.SMTPPassword " .. propertyValue)
	EmailControl:SetPassword(propertyValue)
end






ld_PakedgeEmail = true		--- for development

