--[[=============================================================================
	File is: url_device_specific.lua
	
    Copyright 2021 Wirepath Home Systems, LLC. All Rights Reserved.
===============================================================================]]

--=========================================================================
--=========================================================================
-- Responses


function Resp_GetImageSettings(RespCode, Data)
	LogInfo("Resp_GetImageSettings: RespCode: %d  Data %s", tonumber(RespCode), tostring(Data))
end



function Resp_GetSettings(RespCode, Data)
	LogTrace("Resp_GetSettings: RespCode: %d  Data %s", tonumber(RespCode), tostring(Data))

	if(URL_ResponseIsValid(RespCode)) then
		Camera:GetSettingsSuccess(Data)
	else
		LogInfo("Resp_GetSettings Communication Error")
		Camera:GetSettingsFailure(RespCode)
	end
end


H264Resolutions = {
	["rtsph264qhd"]		= 1440,		-- 2560x1440
	["rtsph2643m169"]	= 1296,		-- 2304x1296
	["rtsph2641080p"]	= 1080,		-- 1920x1080
	["rtsph264qvga"]	= 960,		-- 1280x960
	["rtsph264720p"]	= 720,		-- 1280x720
	["rtsph264576p"]	= 576,		-- 720x576
	["rtsph264480p"]	= 480,		-- 720x480
	["rtsph264vga"]		= 480,		-- 640x480
	["rtsph264cif240"]	= 240		-- 352x240
}

JpegResolutions = {
	["rtspjpeg1080p"]	= 1080,		-- 1920x1080
	["rtspjpeg720p"]	= 720,		-- 1280x720
	["rtspjpeg480p"]	= 480,		-- 640x480
	["rtspjpegcif"]		= 240,		-- 352x240
}


function Resp_GetURLSettings (RespCode, Data)
	LogTrace("Resp_GetURLSettings: RespCode: %d  Data %s", tonumber(RespCode), tostring(Data))

	gH264TEXT = {}		-- start with clean tables
	gJPEGTEXT = {}
	
	for url in string.gmatch(Data, "(.-)\r\n") do
		LogDebug("Resp_GetURLSettings  Check String: %s", tostring(url))
		if (string.find(url, 'h264')) then
			local urlTEXT = string.match (url, 'rtsph264.-$')
			
			local CurRes = H264Resolutions[urlTEXT]
			if(CurRes ~= nil) then
				LogDebug("Add Resolution Support  %d -> %s", CurRes, urlTEXT)
				gH264TEXT[urlTEXT] = CurRes
			else
				LogWarn("RESPONSES.GetURLSettings  Unsupported resolution from camera: %s", urlTEXT)
			end
		end

		if (string.find(url, 'jpeg')) then
			local urlTEXT = string.match (url, 'rtspjpeg.-$')
			
			local CurJRes = JpegResolutions[urlTEXT]
			if(CurJRes ~= nil) then
				LogDebug("Add Jpeg Resolution Support  %d -> %s", CurJRes, urlTEXT)
				gJPEGTEXT[urlTEXT] = CurJRes
			else
				LogWarn("Resp_GetURLSettings  Unsupported JPeg resolution from camera: %s", urlTEXT)
			end
		end
	end
end



function Resp_PingResponse(RespCode, Data)
	LogTrace("Resp_PingResponse: RespCode: %d  Data %s", tonumber(RespCode), tostring(Data))

	if(URL_ResponseIsValid(RespCode)) then
		LogTrace("Ping Successful")
		Camera:SetOnlineStatus(NETWORK_BINDINGID, true, false)
	else
		LogInfo("Ping Failed.  Marking offline")
		Camera:SetOnlineStatus(NETWORK_BINDINGID, false, false)
	end
end



function Resp_MotionSettings(RespCode, Data)
	LogTrace("Resp_MotionSettings: RespCode: %d  Data %s", tonumber(RespCode), tostring(Data))

	Camera:MotionSensitivityFromCamera(tonumber(string.match(Data, "mdSen=([%C]+)%c")))
end


function Resp_GetQuality(RespCode, Data)
	LogTrace("Resp_GetQuality: RespCode: %d  Data %s", tonumber(RespCode), tostring(Data))

	Camera:SaveWhiteBalance(tonumber(string.match(Data, "AWB=([%C]+)%c")))
end



ld_urldevicespecific = true		-- for development

