![](./docassets/control4.png)  

## Overview
This driver enables video from Pakedge IP cameras to be displayed on the control UIs. It also provides contact closures for all available detections. This driver is for IP cameras only. Address each camera separately using these drivers. Do not use this driver for an NVR. This driver does not support camera presets.

Pakedge cameras are SDDP enabled, which allows them to be identified on the system and allows the driver to be automatically added to the project.  

## Known Issues
No known issues. See the Dealer Knowledgebase to search for recent issues.

## Quick Configuration  
- Select the Pakedge model in the Discovery tab and add username and password in properties.  

### Hardware Setup
See the camera’s installation guide for full instructions. Additional tips:  

- The hardware should be set up to suit the individual needs of the project.  
- Make sure that the camera has the latest firmware installed. If you need to update a product that is currently installed, go to dealer.pakedge.com <http://pkdge.co/cam-fw>.  
- If the device is identified as SDDP and is configured as DHCP (default), it is always advisable to set up a MAC-based reservation.  

### Important: 
Pakedge recommends that you enable, configure, and bench test at your office any and all motion, tamper, or other desired functions before implementing it into a Control4 installation.

### Configuration
On the controller's first successful communication with the camera, the driver automatically creates pre-determined connections for the features that are enabled on the camera. The connections that are available for the camera will be available under Composer’s Connections view and can be bound (connected) using standard Control4 device types, such as motion sensors.

- SDDP: If the camera is added to the project using SDDP (recommended), the control connections are automatically configured. Confirm that the camera is on the same IP subnet as the Control4 system.  
- Manual: You can also manually identify the camera via the Connections view > Network tab by entering the camera’s IP address.  

### Setting Properties
- Hostname / IP Address: Will be populated on first successful communication with the camera.  
- HTTP Port: Define the port used by the camera.  
- RTSP (H.264) Port: Define the port used by H.264 streaming.  
- Snapshot Refresh Rate: Set the interval, in seconds, between image captures.  
- Publicly Accessible: Select if you want the camera to be viewable from outside the home network.  
- Authentication: To require authentication, select Required, then enter your security credentials.  

## Setting Advanced Properties

### General Properties
- Log Level: Standard for most drivers; this property allows you to filter which message types display in the Lua Output window. Options 0-5 correspond to Fatal through Trace levels, increasing in level of verbosity. Options are 0 - Fatal, 1 - Error, 2 - Warning, 3 - Info, 4 - Debug, and 5 - Trace. Default is 1 - Error.  
- Log Mode: Activates logging of diagnostic information. The log level is set in the above property. Options include Off, Print (to the window), Log (to the Director Log), and Print and Log (both). Default is Off.  
- Driver Version: (Read only) Shows the version number of the driver currently in use.   
- Driver Information: (Read only) Provides feedback about communication status, such as “unauthorized” and “not found.” Property is “Offline” when the driver is first added to the project. (It will also revert to “Offline” if a ping fails.)  
- When communication is successfully established, the property will be “Communication Established.”  
- When an attempt at communication fails, the property will be “Communication Failure:” followed by the response code (for example, “Communication Failure: Unauthorized”).  
- Camera Name: (Read only) Shows the camera name.  
- Camera Model: (Read only) Shows the camera model number.  
- Firmware: (Read only) Shows the version number of the firmware currently in use on the device. The firmware will be updated automatically over the air when the Control4 OS is updated and when that update includes a new firmware version for this device. You can also look for the latest firmware downloads on the product page at <dealer.pakedge.com>.  
- Detections: (Read only) Lists the types of detections that are enabled.  
- PTZ: (Read only) Shows the type of PTZ that is supported.  
- Zoom Increment: Sets the number of “clicks” performed with each zoom in / zoom out.  
- Sync with C4 Time: When this is set to Yes, the driver will daily synchronize the camera time to the controller's time. Default is No.  

### Settings 
- Motion Sensitivity: Sets amount of movement that triggers motion detection. The default is Standard (level 4). If motion detection is supported, the initial value of this field will be read from the camera. If motion detection is not supported, this property will not be displayed. 
- White Balance: Adjusts image white balance to match ambient lighting types. The default is Auto.  

### Email Options
- Enable Email: Enable email notifications and display email-related properties.  
- Email To Address: Define who will receive the email notification.   
- Email From Address: Define the displayed sender’s email address.  
- SMTP Server: Address or name of SMTP server used to send the email notification.   
Note: When configuring the email settings in the driver, defaults are automatically added for the SMTP Server, SMTP Port, and SSL Login fields for some of the commonly used email SMTP servers (see “Default email settings by SMTP server” below). For other SMTP servers, add the name of the SMTP server, the port used, and whether SSL is used. The most common port used on any SMTP server when SSL is enabled is port 465. It is unlikely, but if SMTP authentication is not being used on your SMTP server, port 25 is used. Contact your SMTP server provider for the required configuration parameters.  
Note: Different SMTP (email) servers may require specific settings to enable use. For example, when using Gmail, the account must have Allow less secure apps enabled on the Gmail account under the Sign in & Security section found under My Account.  
- SMTP Port: Define SMTP port used by the SMTP server.  
- SSL Login: Enable (select Yes) if the SMTP server requires SSL.  
- SMTP Account: Define the SMTP account that will send the email.  
- SMTP Password: Password for the SMTP account that will send the email.  
- Minimum Password Strength Requirements:  
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;1. The password length must be 8 or more characters.  
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;2. The password must include at least 1 number (  0  ~  9  ),1 uppercase letter, 1 lowercase letter  and 1 symbol( ~ ? / + = , : ; . ’ @ # ￥% ^ & * ( ) _ -).  
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;3. Entering an invalid character will cause multiple features to not work. IE. Email snapshots.  
- Email Subject: Set a custom Subject message that will be received by end user.  
- Email Message: Set a custom email message that will be received by end user.  

Tip: Use Send Email Snapshot under Actions to test the email configuration.

## Default email settings by SMTP server
### Gmail (already exists in driver)
SMTP server: smtp.gmail.com
SMTP Port: 465
SSL Login: Yes

### Yahoo (already exists in driver)
SMTP server: smtp.mail.yahoo.com
SMTP Port: 465
SSL Login: Yes

### Hotmail
SMTP server: smtp.live.com
SMTP Port: 587
SSL Login: No

### Zoho
SMTP server: smtp.zoho.com
SMTP Port: 465
SSL Login: Yes

### Mail.com
SMTP server: smtp.mail.com
SMTP Port: 465
SSL Login: Yes

## Composer Device UI Control  
![](./docassets/Image1.png)  
 
### Camera Information
- Address: The IP address assigned to the camera. (DHCP default).   
- Manufacturer: Shows the driver manufacturer.    
- Model: Camera model (all Pakedge cameras appear as “PTZ Models”).
  
### Image View
- Snapshot (default): Select the image capture mode.  
- Manual (default): Select the time interval between captured images.  
- Refresh: Refresh the camera view. 
 
### Pan and Tilt
- Left and right arrows: Pan camera left and right.  
- Up and down arrows: Tilt camera up and down. 
 
### Zoom
- Zooms image in (+) and out (-).  

### Presets
- Press the preset button to change the camera’s view to the configured preset. If viewing the camera’s image in Composer, set the Image View to H.264 to see the changes in real time.   

### Resolution
- Select the resolution of captured images.  

## Programming
As well as the standard Control4 programming actions, the following device-specific commands are available
   
- TIME_SYNC: Set camera time to match current project time.  
- Reinitialize: Re-initializes driver to online configuration.  
- Backlight Compensation: Turn on and off camera Backlighting.     
- SEND_SNAPSHOT: Send a snapshot to the defined email address with the defined subject and message.  
- SET_EMAIL: Update the email address to which the snapshot will be sent.  
- SET_SUBJECT: Update the subject of the snapshot email.  
- SET_MESSAGE: Update the message of the snapshot email.  
- FLIP/UNFLIP_IMAGE: Flip the camera image vertically.  
- MIRROR/UNMIRROR IMAGE: Flip the camera image horizontally.  
- REBOOT_CAMERA: Restart the camera.  
- INC/DEC_IMAGE_VALUE: Enable iris and focus to be adjusted.  
- BACK_LIGHT_COMPENSATION: Turn backlight compensation on or off.  
- WHITE_BALANCE: Set to one of several options.  
- EXPOSURE: Set from 1-16.
- NOISE_REDUCTION_3D: Set between 0 and 32.
- AUTO_GAIN_CONTROL: Set between 2x and 64x.
- ENABLE_IR: Enables IR LEDs.

## Driver Actions  

- Backlight Compensation: Turn backlight compensation on or off.  
- Get Camera Resolution: Get a list of configured resolutions.  
- Enable Motion: Enables motion on camera.  
- Disable Motion: Disables motion on camera.  
- Send Email Snapshot: Tests the email setup. This action requests that the camera send a snapshot using the defined email settings.  
- Update Email Settings: Updates all email settings on the Properties tab by sending them to the camera.  
- Reboot Camera: Sends a command to the camera to reboot. Rebooting may take several minutes.  
- Reinitialize: Re-initializes the driver and connections. Warning: this will recreate any detection contacts and any programming associated with these will be lost.  
- Toggle Mirror: Changes the camera image to a mirror image of itself (flip horizontally).  
- Toggle Flip: Changes the camera image by turning the image upside down (flip vertically).  
- Setup Report: Prints a report on the Lua tab showing the setup and features available on the driver.  
- Sync Time: Synchronizes the camera time to the controller's time.  

## Troubleshooting
If communication cannot be established with the camera or other problems are encountered, look for the following possible causes:  

- Incompatible camera firmware: Ensure the camera is running the latest firmware.  
- Camera not on the same IP subnet as the Control4 controller.  
- Incorrect IP address (if manually configured in Composer’s Connections view).  
- Camera password is not correctly configured in the driver.  
- Contacts not bound correctly to Control4 contact devices.  
- Too high a frame rate. If camera images appear too slowly or skip, reduce the frame rate on the MJPEG or H.264 stream.  

Tip: Run a Setup Report from the Actions tab to get more information that may help you troubleshoot. Note: Not all cameras support all functions. The Setup Report may indicate some features that are not enabled. See the Pakedge documentation for a definitive list of features for each camera model.

### Support
For support on this driver, contact Pakedge or Control4 Technical Support.

### Change Log 
- V226: Add the ability to Sync Time using programming.
- V225: Updated documentation to be displayed in HTML format.
- V224: Fixed bug with Backlight Compensation not showing up in programming and added Backlight Compensation to Actions.
- V223: Added support for push notifications. 
- V222: Added Gif images for driver icons and updated driver.xml with correct gif image file names.
- V221: Consolidate code, fix a crash bug
- V110: First external release.

